==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/it.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Tipo MIME del file",
    "is" : "è",
    "is not" : "non è",
    "matches" : "corrisponde",
    "does not match" : "non corrisponde",
    "Example: {placeholder}" : "Esempio: {placeholder}",
    "File name" : "Nome file",
    "File size (upload)" : "Dimensione file (caricamento)",
    "less" : "minore",
    "less or equals" : "minore o uguale",
    "greater or equals" : "maggiore o uguale",
    "greater" : "maggiore",
    "File system tag" : "Etichetta del file system",
    "is tagged with" : "è etichettato con",
    "is not tagged with" : "non è etichettato con",
    "Select tag…" : "Seleziona etichetta...",
    "Request remote address" : "Indirizzo remoto della richiesta",
    "matches IPv4" : "corrisponde a IPv4",
    "does not match IPv4" : "non corrisponde a IPv4",
    "matches IPv6" : "corrisponde a IPv6",
    "does not match IPv6" : "non corrisponde a IPv6",
    "Request time" : "Ora della richiesta",
    "between" : "compreso",
    "not between" : "non compreso",
    "Start" : "Inizio",
    "End" : "Fine",
    "Select timezone…" : "Seleziona fuso orario...",
    "Request URL" : "URL della richiesta",
    "Predefined URLs" : "URL predefiniti",
    "Files WebDAV" : "File WebDAV",
    "Request user agent" : "User agent della richiesta",
    "Sync clients" : "Client di sincronizzazione",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client desktop",
    "Thunderbird & Outlook addons" : "Componenti aggiuntivi di Outlook e Thunderbird",
    "User group membership" : "Appartenenza ai gruppi degli utenti",
    "is member of" : "è membro di",
    "is not member of" : "non è membro di",
    "Short rule description" : "Descrizione breve della regola",
    "Add rule" : "Aggiungi regola",
    "Reset" : "Ripristina",
    "Save" : "Salva",
    "Saving…" : "Salvataggio in corso...",
    "Group list is empty" : "L'elenco dei gruppi è vuoto",
    "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
    "Saved" : "Salvato",
    "Saving failed:" : "Salvataggio non riuscito:",
    "Add rule group" : "Aggiungi gruppo di regole",
    "The given operator is invalid" : "L'operatore specificato non è valido",
    "The given regular expression is invalid" : "L'espressione regolare specificata non è valida",
    "The given file size is invalid" : "La dimensione del file specificata non è valida",
    "The given tag id is invalid" : "L'etichetta specificata non è valida",
    "The given IP range is invalid" : "L'intervallo di IP specificato non è valido",
    "The given IP range is not valid for IPv4" : "L'intervallo di IP specificato non è valido per IPv4",
    "The given IP range is not valid for IPv6" : "L'intervallo di IP specificato non è valido per IPv6",
    "The given time span is invalid" : "L'intervallo di tempo specificato non è valido",
    "The given start time is invalid" : "L'ora di inizio specificata non è valida",
    "The given end time is invalid" : "L'ora di fine specificata non è valida",
    "The given group does not exist" : "Il gruppo specificato non esiste",
    "Check %s is invalid or does not exist" : "Il controllo %s non è valido o non esiste",
    "Operation #%s does not exist" : "L'operazione #%s non esiste",
    "Operation %s does not exist" : "L'operazione %s non esiste",
    "Operation %s is invalid" : "L'operazione %s non è valida",
    "Check %s does not exist" : "Il controllo %s non esiste",
    "Check %s is invalid" : "Il controllo %s non è valido",
    "Check #%s does not exist" : "Il controllo #%s non esiste",
    "Tag management" : "Gestione etichette",
    "Files workflow engine" : "Motore delle procedure dei file",
    "Open documentation" : "Apri documentazione",
    "Loading…" : "Caricamento in corso...",
    "Workflow" : "Flusso di lavoro"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/it.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'operatore specificato non è valido",
    "The given regular expression is invalid" : "L'espressione regolare specificata non è valida",
    "The given file size is invalid" : "La dimensione del file specificata non è valida",
    "The given tag id is invalid" : "L'etichetta specificata non è valida",
    "The given IP range is invalid" : "L'intervallo di IP specificato non è valido",
    "The given IP range is not valid for IPv4" : "L'intervallo di IP specificato non è valido per IPv4",
    "The given IP range is not valid for IPv6" : "L'intervallo di IP specificato non è valido per IPv6",
    "The given time span is invalid" : "L'intervallo di tempo specificato non è valido",
    "The given start time is invalid" : "L'ora di inizio specificata non è valida",
    "The given end time is invalid" : "L'ora di fine specificata non è valida",
    "The given group does not exist" : "Il gruppo specificato non esiste",
    "File" : "File",
    "File created" : "File creato",
    "File updated" : "File aggiornato",
    "File renamed" : "File rinominato",
    "File deleted" : "File eliminato",
    "File accessed" : "File acceduto",
    "File copied" : "File copiato",
    "Tag assigned" : "Etichetta assegnata",
    "Operation #%s does not exist" : "L'operazione #%s non esiste",
    "Entity %s does not exist" : "L'entità %s non esiste",
    "Entity %s is invalid" : "L'entità %s non è valida",
    "No events are chosen." : "Nessun evento è stato scelto.",
    "Entity %s has no event %s" : "L'entità %s non ha eventi %s",
    "Operation %s does not exist" : "L'operazione %s non esiste",
    "Operation %s is invalid" : "L'operazione %s non è valida",
    "Check %s does not exist" : "Il controllo %s non esiste",
    "Check %s is invalid" : "Il controllo %s non è valido",
    "Check %s is not allowed with this entity" : "Il controllo di %s non è consentito con questa entità",
    "Check #%s does not exist" : "Il controllo #%s non esiste",
    "Check %s is invalid or does not exist" : "Il controllo %s non è valido o non esiste",
    "Workflows" : "Flussi di lavoro",
    "Nextcloud workflow engine" : "Motore flussi di lavoro di Nextcloud",
    "Select a filter" : "Seleziona un filtro",
    "Select a comparator" : "Seleziona un comparatore",
    "Select a file type" : "Seleziona un tipo di file",
    "e.g. httpd/unix-directory" : "ad es. httpd/unix-directory",
    "Images" : "Immagini",
    "Office documents" : "Documenti di Office",
    "PDF documents" : "Documenti PDF",
    "Custom mimetype" : "Tipo MIME personalizzato",
    "Select a tag" : "Seleziona un'etichetta",
    "No results" : "Nessun risultato",
    "%s (invisible)" : "%s (invisibile)",
    "%s (restricted)" : "%s (limitato)",
    "Please enter a valid time span" : "Digita un intervallo temporale valido",
    "Select a request URL" : "Seleziona un URL di richiesta",
    "Predefined URLs" : "URL predefiniti",
    "Files WebDAV" : "File WebDAV",
    "Others" : "Altri",
    "Custom URL" : "URL personalizzato",
    "Select a user agent" : "Seleziona user agent",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client desktop",
    "Thunderbird & Outlook addons" : "Componenti aggiuntivi di Outlook e Thunderbird",
    "Custom user agent" : "User agent personalizzato",
    "When" : "Quando",
    "and" : "e",
    "Cancel" : "Annulla",
    "Delete" : "Elimina",
    "The configuration is invalid" : "La configurazione non è valida",
    "Show less" : "Mostra meno",
    "Show more" : "Mostra più",
    "File name" : "Nome file",
    "is" : "è",
    "is not" : "non è",
    "matches" : "corrisponde",
    "does not match" : "non corrisponde",
    "File MIME type" : "Tipo MIME del file",
    "File size (upload)" : "Dimensione file (caricamento)",
    "less" : "minore",
    "less or equals" : "minore o uguale",
    "greater or equals" : "maggiore o uguale",
    "greater" : "maggiore",
    "Request remote address" : "Indirizzo remoto della richiesta",
    "matches IPv4" : "corrisponde a IPv4",
    "does not match IPv4" : "non corrisponde a IPv4",
    "matches IPv6" : "corrisponde a IPv6",
    "does not match IPv6" : "non corrisponde a IPv6",
    "File system tag" : "Etichetta del file system",
    "is tagged with" : "è etichettato con",
    "is not tagged with" : "non è etichettato con",
    "Request URL" : "URL della richiesta",
    "Request time" : "Ora della richiesta",
    "between" : "compreso",
    "not between" : "non compreso",
    "Request user agent" : "User agent della richiesta",
    "User group membership" : "Appartenenza ai gruppi degli utenti",
    "is member of" : "è membro di",
    "is not member of" : "non è membro di",
    "Short rule description" : "Descrizione breve della regola",
    "Add rule" : "Aggiungi regola",
    "Reset" : "Ripristina",
    "Save" : "Salva",
    "Saving…" : "Salvataggio in corso...",
    "Group list is empty" : "L'elenco dei gruppi è vuoto",
    "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
    "Saved" : "Salvato",
    "Saving failed:" : "Salvataggio non riuscito:",
    "Add rule group" : "Aggiungi gruppo di regole",
    "Example: {placeholder}" : "Esempio: {placeholder}",
    "Select tag…" : "Seleziona etichetta...",
    "Start" : "Inizio",
    "End" : "Fine",
    "Select timezone…" : "Seleziona fuso orario...",
    "Sync clients" : "Client di sincronizzazione",
    "Workflow" : "Flusso di lavoro",
    "Files workflow engine" : "Motore delle procedure dei file",
    "Open documentation" : "Apri documentazione",
    "Loading…" : "Caricamento in corso...",
    "Tag management" : "Gestione etichette"
},
"nplurals=2; plural=(n != 1);");
